@@ -56,19 +56,18 @@ sub install {
     } keys %install;
   };
 
+  _check_mkdir($config->{prefix});
   local $CWD = $config->{prefix};
 
   foreach my $folder (keys %files) {
-    mkdir $folder unless -d $folder;
+    _check_mkdir($folder);
     local $CWD = $folder;
-    copy $_, $CWD for @{$files{$folder}};
+    foreach my $file (@{$files{$folder}}) {
+      copy $file, $CWD or die "Could not copy file $file";
+    }
+    _write_pc() if $folder eq 'lib';
   }
 
-  {
-    local $CWD = 'lib';
-    _write_pc();
-    
-  }
 }
 
 sub clean {
@@ -109,3 +108,10 @@ Cflags: -I$prefix/include
 END_PC
 }
 
+sub _check_mkdir {
+  my $folder = shift;
+  unless (-d $folder) {
+    mkdir $folder or die "Could not create folder: $folder";
+  }
+}
+
